@@ -530,7 +530,7 @@ def fail_usage(message="", stop=True):
 		logging.error("Please use '-h' for usage\n")
 		sys.exit(EC_GENERIC_ERROR)
 
-def fail(error_code):
+def fail(error_code, stop=True):
 	message = {
 		EC_LOGIN_DENIED : "Unable to connect/login to fencing device",
 		EC_CONNECTION_LOST : "Connection lost",
@@ -546,7 +546,8 @@ def fail(error_code):
 
 	}[error_code] + "\n"
 	logging.error("%s\n", message)
-	sys.exit(EC_GENERIC_ERROR)
+	if stop:
+		sys.exit(EC_GENERIC_ERROR)
 
 def usage(avail_opt):
 	print("Usage:")
@@ -571,7 +572,7 @@ def metadata(options, avail_opt, docs):
 	sorted_list.sort(key=lambda x: (x[1]["order"], x[0]))
 
 	if options["--action"] == "metadata":
-		docs["longdesc"] = re.sub("\.P|\.TP|\.br\n", "", docs["longdesc"])
+               docs["longdesc"] = re.sub("\\\\f[BPIR]|\.P|\.TP|\.br\n", "", docs["longdesc"])
 
 	print("<?xml version=\"1.0\" ?>")
 	print("<resource-agent name=\"" + os.path.basename(sys.argv[0]) + \
@@ -1009,7 +1010,7 @@ def run_command(options, command, timeout=None, env=None, log_command=None):
 	thread.join(timeout)
 	if thread.is_alive():
 		process.kill()
-		fail(EC_TIMED_OUT)
+		fail(EC_TIMED_OUT, stop=(int(options.get("retry", 0)) < 1))
 
 	status = process.wait()
 
